#!/bin/bash
SCRIPT_DIR="$(cd "$(dirname "${BASH_SOURCE[0]}")" >/dev/null 2>&1 && pwd)"

set -e

# set current directory
cwd=$(pwd)

source ${SCRIPT_DIR}/utils/io.sh

MYSQL_DIR=${cwd}/mysql
MYSQL_DUMP_DIR=${MYSQL_DIR}/dumps
LEGACY_STARTUP_FILE=${MYSQL_DIR}/startup.sql
STARTUP_FILE=${MYSQL_DIR}/startup.sql.gz
DEFAULT_STARTUP_BACKUP_FILE_NAME="startup-$(date +"%F-%H%M%S")"

function createBackupFile() {
    local __FILE=${1}
    local __FILE_NAME=${2}
    local __LOCATION=${3:-${MYSQL_DUMP_DIR}}

    BACKUP_FILE=${__LOCATION}/${__FILE_NAME}.sql.gz

    # If backup file already exist we prompt for confirmation before overriding the existing backup file
    if [[ -e ${BACKUP_FILE} ]] && ioWarning "${BACKUP_FILE} already exists" && ! $(ioConfirm "Override existing file"); then
        i=1
        while [[ -e ${__LOCATION}/${__FILE_NAME}-${i}.sql.gz ]]; do
            let i++
        done
        BACKUP_FILE=${__LOCATION}/${__FILE_NAME}-${i}.sql.gz
    fi

    ioInfo "Copy ${__FILE} -> ${BACKUP_FILE}"
    cp ${__FILE} ${BACKUP_FILE}
}

mkdir -p ${MYSQL_DUMP_DIR}

if [ $(ls -1 ${MYSQL_DUMP_DIR}/*.sql.gz 2>/dev/null | wc -l) == 0 ]; then
    ioInfo "You have no dumps to import, run \`make mysql-dump\` to create one." && exit 1
fi

files=($(ls -A1 ${MYSQL_DUMP_DIR}/*.sql.gz))

filesForSelect=(${files[@]#${cwd}})

fileCount=${#files[@]}
ioBoldText "Choose a dump file to import($(if [[ ${fileCount} -gt 1 ]]; then echo "1-${fileCount}"; else echo "1"; fi))"
echo "--------------------------------------------------------------------------------------"
select relativefileMatch in "${filesForSelect[@]}"; do
    if [[ -n ${relativefileMatch} ]]; then
        DUMP_FILE="${cwd}${relativefileMatch}"
        break
    fi

    ioBoldText "Choose the file by entering its number! $(if [[ ${fileCount} -gt 1 ]]; then echo "1-${fileCount}"; else echo "1"; fi))"
done
echo "--------------------------------------------------------------------------------------"

read -p "Name of backup file [${DEFAULT_STARTUP_BACKUP_FILE_NAME}]: " STARTUP_BACKUP_FILE_NAME

if [[ -z "${STARTUP_BACKUP_FILE_NAME}" ]]; then
    STARTUP_BACKUP_FILE_NAME=${DEFAULT_STARTUP_BACKUP_FILE_NAME}
fi

# Compress legacy startup
[[ -f ${STARTUP_FILE} ]] || [[ ! -f ${LEGACY_STARTUP_FILE} ]] || gzip --best ${LEGACY_STARTUP_FILE} >${STARTUP_FILE}

createBackupFile ${STARTUP_FILE} ${STARTUP_BACKUP_FILE_NAME}

ioInfo "Copy ${DUMP_FILE} -> ${STARTUP_FILE}"
cp ${DUMP_FILE} ${STARTUP_FILE}

ioSuccess "Successfully switched startup.sql"
